pub struct AdaptiveLink { /* private fields */ }Expand description
Adaptive-link quality estimator and feedback payload builder.
Implementations
Sourceimpl AdaptiveLink
impl AdaptiveLink
Sourcepub fn record_rx_paths(&mut self, now_ms: u64, rssi: [u8; 4], snr: [i8; 4])
pub fn record_rx_paths(&mut self, now_ms: u64, rssi: [u8; 4], snr: [i8; 4])
Record RSSI/SNR arrays from a Realtek RX descriptor.
Sourcepub fn record_rx(
&mut self,
now_ms: u64,
rssi0: u8,
rssi1: u8,
snr0: i8,
snr1: i8,
)
pub fn record_rx( &mut self, now_ms: u64, rssi0: u8, rssi1: u8, snr0: i8, snr1: i8, )
Record RSSI/SNR for the first two RF paths.
Sourcepub fn record_fec(&mut self, now_ms: u64, total: u32, recovered: u32, lost: u32)
pub fn record_fec(&mut self, now_ms: u64, total: u32, recovered: u32, lost: u32)
Record FEC totals for the current quality window.
Sourcepub fn request_keyframe(&mut self)
pub fn request_keyframe(&mut self)
Request keyframes in upcoming feedback packets.
Sourcepub fn set_keyframe_request_messages(&mut self, messages: u32)
pub fn set_keyframe_request_messages(&mut self, messages: u32)
Configure how many feedback packets carry a keyframe request.
Sourcepub fn set_video_start_idle_ms(&mut self, idle_ms: u64)
pub fn set_video_start_idle_ms(&mut self, idle_ms: u64)
Configure the idle duration after which new video asks for keyframes.
Sourcepub fn quality(&mut self, now_ms: u64) -> LinkQuality
pub fn quality(&mut self, now_ms: u64) -> LinkQuality
Compute current quality over the rolling window.