pub struct ChannelId(/* private fields */);Expand description
OpenIPC/WFB logical channel id.
The high 24 bits are the link id and the low byte is the radio port.
Implementations
Sourceimpl ChannelId
impl ChannelId
Sourcepub const fn from_link_port(link_id: u32, port: RadioPort) -> Self
pub const fn from_link_port(link_id: u32, port: RadioPort) -> Self
Build a channel id from a link id and radio port.
Sourcepub const fn default_video() -> Self
pub const fn default_video() -> Self
Return the default OpenIPC video channel.
Sourcepub const fn to_be_bytes(self) -> [u8; 4]
pub const fn to_be_bytes(self) -> [u8; 4]
Return the raw channel id encoded for 802.11 address fields.