Module receiver

Module receiver 

Higher-level receive runtime for video and payload routes.

Structs

ReceiverBatch
Output produced from one transfer, packet list, frame, or fragment push.
ReceiverBatchCounters
Counters collected while processing one receive batch.
ReceiverBatchOptions
Options that control how one receive batch is processed.
ReceiverRuntime
Shared receive runtime for OpenIPC video plus optional raw payload taps.
RoutePayload
Recovered WFB payload bytes copied for an application route.
RtpPayloadTap
Filter for copying RTP packets from a recovered route.