pub enum PayloadRouteEvent {
IgnoredFrame,
SessionEstablished {
runtime: PayloadRuntimeKey,
route_ids: Arc<[PayloadRouteId]>,
epoch: u64,
fec_k: usize,
fec_n: usize,
},
Payload {
runtime: PayloadRuntimeKey,
route_ids: Arc<[PayloadRouteId]>,
payload: RecoveredPayload,
},
}Expand description
Event emitted by route-manager processing.
Variants
IgnoredFrame
Frame did not match any configured route or usable payload.
SessionEstablished
A WFB session packet established or refreshed a runtime session.
Fields

runtime: PayloadRuntimeKeyRuntime whose WFB session changed.

route_ids: Arc<[PayloadRouteId]>Route ids attached to the runtime.
Payload
A recovered payload was emitted by a runtime.
Fields

runtime: PayloadRuntimeKeyRuntime that recovered the payload.

route_ids: Arc<[PayloadRouteId]>Route ids that should receive the payload.

payload: RecoveredPayloadRecovered payload bytes and packet metadata.