CodecConfigState

Struct CodecConfigState 

pub struct CodecConfigState {
    pub h264_sps: bool,
    pub h264_pps: bool,
    pub h265_vps: bool,
    pub h265_sps: bool,
    pub h265_pps: bool,
}
Decoder configuration NAL units observed by the RTP depacketizer.

H.264 needs SPS and PPS before a decoder can be configured. H.265 needs VPS, SPS and PPS. PixelPilot starts its decoder as soon as these parameter sets have been observed, then feeds subsequent NAL units without requiring a fresh IDR for every startup path.

Fields

h264_sps: bool

H.264 sequence parameter set has been seen.

h264_pps: bool

H.264 picture parameter set has been seen.

h265_vps: bool

H.265 video parameter set has been seen.

h265_sps: bool

H.265 sequence parameter set has been seen.

h265_pps: bool

H.265 picture parameter set has been seen.

Implementations

Source

impl CodecConfigState

pub const fn is_complete_for(self, codec: Codec) -> bool

Return true when all parameter sets required for codec are cached.