pub struct DepacketizedFrame {
pub data: Vec<u8>,
pub timestamp: u32,
pub is_keyframe: bool,
pub codec: Codec,
pub payload_type: u8,
pub sequence_number: u16,
pub nal_type: u8,
pub codec_config: CodecConfigState,
}Expand description
Encoded Annex-B H.264/H.265 access unit emitted by RtpDepacketizer.
Fields
data: Vec<u8>Annex-B byte stream data including start codes.
timestamp: u32RTP timestamp associated with the access unit.
is_keyframe: boolTrue when the frame contains an IDR/keyframe entry point.
codec: CodecVideo codec for this frame.
payload_type: u8RTP payload type that produced this frame.
sequence_number: u16RTP sequence number of the packet that completed this frame.
nal_type: u8H.264/H.265 NAL unit type for the frame payload.
codec_config: CodecConfigStateDecoder parameter-set state at the time this frame was emitted.