pub struct ReceiverBatchOptions {
pub accept_corrupted: bool,
pub raw_payload_routes: Vec<PayloadRouteId>,
pub rtp_payload_taps: Vec<RtpPayloadTap>,
}Expand description
Options that control how one receive batch is processed.
Fields
accept_corrupted: boolKeep CRC/ICV-marked packets instead of dropping them before WFB parsing.
raw_payload_routes: Vec<PayloadRouteId>Route ids whose recovered payload bytes should be copied into the batch.
rtp_payload_taps: Vec<RtpPayloadTap>RTP payload-type filters whose matching packets should be copied.